@@ -20,7 +20,7 @@ const config: TestRunnerConfig = {
 
         // If you want to take screenshot of multiple browsers, use
         // page.context().browser().browserType().name() to get the browser name to prefix the file name
-        const image = await page.screenshot();
+        const image = await page.screenshot({ animations: "disabled" });
         expect(image).toMatchImageSnapshot({
             customSnapshotsDir,
             customSnapshotIdentifier: `${context.id}-${process.platform}`,
