@@ -5,14 +5,13 @@
  * Please see LICENSE files in the repository root for full details.
  */
 
-import { type TranslationKey } from "../i18nKeys";
 import { I18nApi } from "./I18nApi";
 
 describe("I18nApi", () => {
     it("can register a translation and use it", () => {
         const i18n = new I18nApi();
         i18n.register({
-            "hello.world": {
+            ["hello.world" as TranslationKey]: {
                 en: "Hello, World!",
             },
         });
