@@ -23,7 +23,9 @@ async function uploadFile(page: Page, file: string) {
 
     // Wait until the file is sent
     await expect(page.locator(".mx_RoomView_statusArea_expanded")).not.toBeVisible();
-    await expect(page.locator(".mx_EventTile.mx_EventTile_last .mx_EventTile_receiptSent")).toBeVisible();
+    await expect(page.locator(".mx_EventTile.mx_EventTile_last").getByRole("status")).toHaveAccessibleName(
+        "Your message was sent",
+    );
 }
 
 test.describe("FilePanel", () => {
