@@ -112,7 +112,7 @@ export default class CreateSecretStorageDialog extends React.PureComponent<IProp
         if (keyFromCustomisations) this.initExtension(keyFromCustomisations);
     }
 
-    private initExtension(keyFromCustomisations: Uint8Array): void {
+    private initExtension(keyFromCustomisations: Uint8Array<ArrayBuffer>): void {
         logger.log("CryptoSetupExtension: Created key via extension, jumping to bootstrap step");
         this.recoveryKey = {
             privateKey: keyFromCustomisations,
@@ -351,7 +351,6 @@ export default class CreateSecretStorageDialog extends React.PureComponent<IProp
                 outlined
             >
                 <div className="mx_CreateSecretStorageDialog_optionTitle">
-                    <span className="mx_CreateSecretStorageDialog_optionIcon mx_CreateSecretStorageDialog_optionIcon_secureBackup" />
                     {_t("settings|key_backup|setup_secure_backup|generate_security_key_title")}
                 </div>
                 <div>{_t("settings|key_backup|setup_secure_backup|generate_security_key_description")}</div>
@@ -370,7 +369,6 @@ export default class CreateSecretStorageDialog extends React.PureComponent<IProp
                 outlined
             >
                 <div className="mx_CreateSecretStorageDialog_optionTitle">
-                    <span className="mx_CreateSecretStorageDialog_optionIcon mx_CreateSecretStorageDialog_optionIcon_securePhrase" />
                     {_t("settings|key_backup|setup_secure_backup|enter_phrase_title")}
                 </div>
                 <div>{_t("settings|key_backup|setup_secure_backup|use_phrase_only_you_know")}</div>
@@ -694,19 +692,6 @@ export default class CreateSecretStorageDialog extends React.PureComponent<IProp
 
         let titleClass: string | string[] | undefined;
         switch (this.state.phase) {
-            case Phase.Passphrase:
-            case Phase.PassphraseConfirm:
-                titleClass = [
-                    "mx_CreateSecretStorageDialog_titleWithIcon",
-                    "mx_CreateSecretStorageDialog_securePhraseTitle",
-                ];
-                break;
-            case Phase.ShowKey:
-                titleClass = [
-                    "mx_CreateSecretStorageDialog_titleWithIcon",
-                    "mx_CreateSecretStorageDialog_secureBackupTitle",
-                ];
-                break;
             case Phase.ChooseKeyPassphrase:
                 titleClass = "mx_CreateSecretStorageDialog_centeredTitle";
                 break;
