@@ -14,7 +14,10 @@ import {
     GroupIcon,
     PlusIcon,
     RoomIcon,
+    SettingsSolidIcon,
+    UserAddIcon,
     UserProfileSolidIcon,
+    VideoCallSolidIcon,
 } from "@vector-im/compound-design-tokens/assets/web/icons";
 
 import MatrixClientContext from "../../contexts/MatrixClientContext";
@@ -72,7 +75,6 @@ import MainSplit from "./MainSplit";
 import RightPanel from "./RightPanel";
 import SpaceHierarchy, { showRoom } from "./SpaceHierarchy";
 import { type RoomPermalinkCreator } from "../../utils/permalinks/Permalinks";
-import { Icon as HashVideoIcon } from "../../../res/img/element-icons/roomlist/hash-video.svg";
 import SpacePillButton from "./SpacePillButton.tsx";
 
 interface IProps {
@@ -140,7 +142,7 @@ const SpaceLandingAddButton: React.FC<{ space: Room }> = ({ space }) => {
                             {videoRoomsEnabled && (
                                 <IconizedContextMenuOption
                                     label={_t("action|new_video_room")}
-                                    icon={<HashVideoIcon />}
+                                    icon={<VideoCallSolidIcon />}
                                     onClick={async (e): Promise<void> => {
                                         e.preventDefault();
                                         e.stopPropagation();
@@ -231,6 +233,7 @@ const SpaceLanding: React.FC<{ space: Room }> = ({ space }) => {
                     showSpaceInvite(space);
                 }}
             >
+                <UserAddIcon />
                 {_t("action|invite")}
             </AccessibleButton>
         );
@@ -254,7 +257,9 @@ const SpaceLanding: React.FC<{ space: Room }> = ({ space }) => {
                 }}
                 title={_t("common|settings")}
                 placement="bottom"
-            />
+            >
+                <SettingsSolidIcon />
+            </AccessibleButton>
         );
     }
 
@@ -578,10 +583,8 @@ const SpaceSetupPrivateInvite: React.FC<{
             </form>
 
             <div className="mx_SpaceRoomView_inviteTeammates_buttons">
-                <AccessibleButton
-                    className="mx_SpaceRoomView_inviteTeammates_inviteDialogButton"
-                    onClick={() => showRoomInviteDialog(space.roomId)}
-                >
+                <AccessibleButton onClick={() => showRoomInviteDialog(space.roomId)}>
+                    <UserAddIcon />
                     {_t("create_space|invite_teammates_by_username")}
                 </AccessibleButton>
             </div>
