@@ -20,10 +20,6 @@ import IconizedContextMenu, {
     IconizedContextMenuRadio,
 } from "../context_menus/IconizedContextMenu";
 import { type ButtonEvent } from "../elements/AccessibleButton";
-import { Icon as NotificationsIcon } from "../../../../res/img/element-icons/notifications.svg";
-import { Icon as NotificationsDefaultIcon } from "../../../../res/img/element-icons/roomlist/notifications-default.svg";
-import { Icon as NotificationsDmIcon } from "../../../../res/img/element-icons/roomlist/notifications-dm.svg";
-import { Icon as NotificationsOffIcon } from "../../../../res/img/element-icons/roomlist/notifications-off.svg";
 
 interface IProps extends IContextMenuProps {
     room: Room;
@@ -50,7 +46,6 @@ export const RoomNotificationContextMenu: React.FC<IProps> = ({ room, onFinished
         <IconizedContextMenuRadio
             label={_t("room|context_menu|notifications_default")}
             active={notificationState === RoomNotifState.AllMessages}
-            icon={<NotificationsIcon />}
             onClick={wrapHandler(() => setNotificationState(RoomNotifState.AllMessages))}
         />
     );
@@ -59,7 +54,6 @@ export const RoomNotificationContextMenu: React.FC<IProps> = ({ room, onFinished
         <IconizedContextMenuRadio
             label={_t("notifications|all_messages")}
             active={notificationState === RoomNotifState.AllMessagesLoud}
-            icon={<NotificationsDefaultIcon />}
             onClick={wrapHandler(() => setNotificationState(RoomNotifState.AllMessagesLoud))}
         />
     );
@@ -68,7 +62,6 @@ export const RoomNotificationContextMenu: React.FC<IProps> = ({ room, onFinished
         <IconizedContextMenuRadio
             label={_t("notifications|mentions_keywords")}
             active={notificationState === RoomNotifState.MentionsOnly}
-            icon={<NotificationsDmIcon />}
             onClick={wrapHandler(() => setNotificationState(RoomNotifState.MentionsOnly))}
         />
     );
@@ -77,7 +70,6 @@ export const RoomNotificationContextMenu: React.FC<IProps> = ({ room, onFinished
         <IconizedContextMenuRadio
             label={_t("room|context_menu|notifications_mute")}
             active={notificationState === RoomNotifState.Mute}
-            icon={<NotificationsOffIcon />}
             onClick={wrapHandler(() => setNotificationState(RoomNotifState.Mute))}
         />
     );
