@@ -8,6 +8,7 @@ Please see LICENSE files in the repository root for full details.
 
 import React, { type DetailedHTMLProps, type AnchorHTMLAttributes } from "react";
 import classNames from "classnames";
+import PopOutIcon from "@vector-im/compound-design-tokens/assets/web/icons/pop-out";
 
 interface Props extends DetailedHTMLProps<AnchorHTMLAttributes<HTMLAnchorElement>, HTMLAnchorElement> {}
 
@@ -17,7 +18,7 @@ interface Props extends DetailedHTMLProps<AnchorHTMLAttributes<HTMLAnchorElement
 const ExternalLink: React.FC<Props> = ({ children, className, ...rest }) => (
     <a target="_blank" rel="noreferrer noopener" {...rest} className={classNames("mx_ExternalLink", className)}>
         {children}
-        <i className="mx_ExternalLink_icon" />
+        <PopOutIcon className="mx_ExternalLink_icon" />
     </a>
 );
 
