@@ -22,7 +22,7 @@ const MapFallback: React.FC<Props> = ({ className, isLoading, children, ...rest
     return (
         <div className={classNames("mx_MapFallback", className)} {...rest}>
             <MapFallbackImage className="mx_MapFallback_bg" />
-            {isLoading ? <Spinner h={32} w={32} /> : <LocationMarkerIcon className="mx_MapFallback_icon" />}
+            {isLoading ? <Spinner size={32} /> : <LocationMarkerIcon className="mx_MapFallback_icon" />}
             {children}
         </div>
     );
