@@ -11,6 +11,7 @@ import classNames from "classnames";
 import { type MatrixEvent, MatrixEventEvent, type Relations, RelationsEvent } from "matrix-js-sdk/src/matrix";
 import { uniqBy } from "lodash";
 import { UnstableValue } from "matrix-js-sdk/src/NamespacedValue";
+import { ReactionAddIcon } from "@vector-im/compound-design-tokens/assets/web/icons";
 
 import { _t } from "../../../languageHandler";
 import { isContentActionable } from "../../../utils/EventUtils";
@@ -54,7 +55,9 @@ const ReactButton: React.FC<IProps> = ({ mxEvent, reactions }) => {
                 }}
                 isExpanded={menuDisplayed}
                 ref={button}
-            />
+            >
+                <ReactionAddIcon />
+            </ContextMenuTooltipButton>
 
             {contextMenu}
         </React.Fragment>
