@@ -8,6 +8,7 @@ Please see LICENSE files in the repository root for full details.
 
 import React from "react";
 import { EventTimeline } from "matrix-js-sdk/src/matrix";
+import { VisibilityOffIcon } from "@vector-im/compound-design-tokens/assets/web/icons";
 
 import EventTileBubble from "../messages/EventTileBubble";
 import { _t } from "../../../languageHandler";
@@ -28,6 +29,7 @@ const HistoryTile: React.FC = () => {
 
     return (
         <EventTileBubble
+            icon={<VisibilityOffIcon />}
             className="mx_HistoryTile"
             title={_t("timeline|historical_messages_unavailable")}
             subtitle={subtitle}
