@@ -15,6 +15,14 @@ import {
     M_POLL_START,
 } from "matrix-js-sdk/src/matrix";
 import React, { type JSX, createContext, type ReactElement, type ReactNode, useContext, useRef } from "react";
+import {
+    AttachmentIcon,
+    MicOnIcon,
+    OverflowHorizontalIcon,
+    PollsIcon,
+    StickerIcon,
+    TextFormattingIcon,
+} from "@vector-im/compound-design-tokens/assets/web/icons";
 
 import { _t } from "../../../languageHandler";
 import { CollapsibleButton } from "./CollapsibleButton";
@@ -125,7 +133,9 @@ const MessageComposerButtons: React.FC<IProps> = (props: IProps) => {
                     className={moreOptionsClasses}
                     onClick={props.toggleButtonMenu}
                     title={_t("quick_settings|sidebar_settings")}
-                />
+                >
+                    <OverflowHorizontalIcon />
+                </AccessibleButton>
             )}
             {props.isMenuOpen && (
                 <IconizedContextMenu
@@ -235,12 +245,9 @@ const UploadButton: React.FC = () => {
     };
 
     return (
-        <CollapsibleButton
-            className="mx_MessageComposer_button"
-            iconClassName="mx_MessageComposer_upload"
-            onClick={onClick}
-            title={_t("common|attachment")}
-        />
+        <CollapsibleButton className="mx_MessageComposer_button" onClick={onClick} title={_t("common|attachment")}>
+            <AttachmentIcon />
+        </CollapsibleButton>
     );
 };
 
@@ -250,10 +257,11 @@ function showStickersButton(props: IProps): ReactElement | null {
             id="stickersButton"
             key="controls_stickers"
             className="mx_MessageComposer_button"
-            iconClassName="mx_MessageComposer_stickers"
             onClick={() => props.setStickerPickerOpen(!props.isStickerPickerOpen)}
             title={props.isStickerPickerOpen ? _t("composer|close_sticker_picker") : _t("common|sticker")}
-        />
+        >
+            <StickerIcon />
+        </CollapsibleButton>
     ) : null;
 }
 
@@ -263,10 +271,11 @@ function voiceRecordingButton(props: IProps, narrow: boolean): ReactElement | nu
         <CollapsibleButton
             key="voice_message_send"
             className="mx_MessageComposer_button"
-            iconClassName="mx_MessageComposer_voiceMessage"
             onClick={props.onRecordStartEndClick}
             title={_t("composer|voice_message_button")}
-        />
+        >
+            <MicOnIcon />
+        </CollapsibleButton>
     );
 }
 
@@ -318,10 +327,11 @@ class PollButton extends React.PureComponent<IPollButtonProps> {
         return (
             <CollapsibleButton
                 className="mx_MessageComposer_button"
-                iconClassName="mx_MessageComposer_poll"
                 onClick={this.onCreateClick}
                 title={_t("composer|poll_button")}
-            />
+            >
+                <PollsIcon />
+            </CollapsibleButton>
         );
     }
 }
@@ -349,15 +359,9 @@ function ComposerModeButton({ isRichTextEnabled, onClick }: WysiwygToggleButtonP
     const title = isRichTextEnabled ? _t("composer|mode_plain") : _t("composer|mode_rich_text");
 
     return (
-        <CollapsibleButton
-            className="mx_MessageComposer_button"
-            iconClassName={classNames({
-                mx_MessageComposer_plain_text: !isRichTextEnabled,
-                mx_MessageComposer_rich_text: isRichTextEnabled,
-            })}
-            onClick={onClick}
-            title={title}
-        />
+        <CollapsibleButton className="mx_MessageComposer_button" onClick={onClick} title={title}>
+            <TextFormattingIcon />
+        </CollapsibleButton>
     );
 }
 
