@@ -5,15 +5,14 @@
  * Please see LICENSE files in the repository root for full details.
  */
 
-import React, { useCallback, useRef, type JSX } from "react";
+import React, { useCallback, useRef, type JSX, useMemo } from "react";
 import { type Room } from "matrix-js-sdk/src/matrix";
-import { type ScrollIntoViewLocation } from "react-virtuoso";
 import { isEqual } from "lodash";
 
 import { type RoomListViewState } from "../../../viewmodels/roomlist/RoomListViewModel";
 import { _t } from "../../../../languageHandler";
 import { RoomListItemView } from "./RoomListItemView";
-import { type ListContext, ListView } from "../../../utils/ListView";
+import { type ListContext, ListView, type ScrollIntoViewOnChange } from "../../../utils/ListView";
 import { type FilterKey } from "../../../../stores/room-list-v3/skip-list/filters";
 import { getKeyBindingsManager } from "../../../../KeyBindingsManager";
 import { KeyBindingAction } from "../../../../accessibility/KeyboardShortcuts";
@@ -25,6 +24,12 @@ interface RoomListProps {
      */
     vm: RoomListViewState;
 }
+
+type Context = {
+    spaceId: string;
+    filterKeys: FilterKey[] | undefined;
+};
+
 /**
  * Height of a single room list item
  */
@@ -48,10 +53,7 @@ export function RoomList({ vm: { roomsResult, activeIndex } }: RoomListProps): J
         (
             index: number,
             item: Room,
-            context: ListContext<{
-                spaceId: string;
-                filterKeys: FilterKey[] | undefined;
-            }>,
+            context: ListContext<Context>,
             onFocus: (item: Room, e: React.FocusEvent) => void,
         ): JSX.Element => {
             const itemKey = item.roomId;
@@ -78,10 +80,8 @@ export function RoomList({ vm: { roomsResult, activeIndex } }: RoomListProps): J
         return item.roomId;
     }, []);
 
-    const scrollIntoViewOnChange = useCallback(
-        (params: {
-            context: ListContext<{ spaceId: string; filterKeys: FilterKey[] | undefined }>;
-        }): ScrollIntoViewLocation | null | undefined | false | void => {
+    const scrollIntoViewOnChange = useCallback<ScrollIntoViewOnChange<Room, Context>>(
+        (params) => {
             const { spaceId, filterKeys } = params.context.context;
             const shouldScrollIndexIntoView =
                 lastSpaceId.current !== spaceId || !isEqual(lastFilterKeys.current, filterKeys);
@@ -112,10 +112,14 @@ export function RoomList({ vm: { roomsResult, activeIndex } }: RoomListProps): J
             return;
         }
     }, []);
+    const context = useMemo<Context>(
+        () => ({ spaceId: roomsResult.spaceId, filterKeys: roomsResult.filterKeys }),
+        [roomsResult.spaceId, roomsResult.filterKeys],
+    );
 
     return (
         <ListView
-            context={{ spaceId: roomsResult.spaceId, filterKeys: roomsResult.filterKeys }}
+            context={context}
             scrollIntoViewOnChange={scrollIntoViewOnChange}
             initialTopMostItemIndex={activeIndex}
             data-testid="room-list"
