@@ -23,7 +23,6 @@ import {
     useRoomListHeaderViewModel,
 } from "../../../viewmodels/roomlist/RoomListHeaderViewModel";
 import { RoomListOptionsMenu } from "./RoomListOptionsMenu";
-import { ReleaseAnnouncement } from "../../../structures/ReleaseAnnouncement";
 
 /**
  * The header view for the room list
@@ -46,38 +45,23 @@ export function RoomListHeaderView(): JSX.Element {
                 {vm.displaySpaceMenu && <SpaceMenu vm={vm} />}
             </Flex>
             <Flex align="center" gap="var(--cpd-space-2x)">
-                <ReleaseAnnouncement
-                    feature="newRoomList_sort"
-                    header={_t("room_list|release_announcement|sort|title")}
-                    description={_t("room_list|release_announcement|sort|description")}
-                    closeLabel={_t("room_list|release_announcement|next")}
-                    placement="bottom"
-                >
-                    <div className="mx_RoomListHeaderView_ReleaseAnnouncementAnchor">
-                        <RoomListOptionsMenu vm={vm} />
-                    </div>
-                </ReleaseAnnouncement>
+                <div className="mx_RoomListHeaderView_ReleaseAnnouncementAnchor">
+                    <RoomListOptionsMenu vm={vm} />
+                </div>
 
                 {/* If we don't display the compose menu, it means that the user can only send DM */}
-                <ReleaseAnnouncement
-                    feature="newRoomList_intro"
-                    header={_t("room_list|release_announcement|intro|title")}
-                    description={_t("room_list|release_announcement|intro|description")}
-                    closeLabel={_t("room_list|release_announcement|next")}
-                >
-                    <div className="mx_RoomListHeaderView_ReleaseAnnouncementAnchor">
-                        {vm.displayComposeMenu ? (
-                            <ComposeMenu vm={vm} />
-                        ) : (
-                            <IconButton
-                                onClick={(e) => vm.createChatRoom(e.nativeEvent)}
-                                tooltip={_t("action|new_conversation")}
-                            >
-                                <ComposeIcon color="var(--cpd-color-icon-secondary)" aria-hidden />
-                            </IconButton>
-                        )}
-                    </div>
-                </ReleaseAnnouncement>
+                <div className="mx_RoomListHeaderView_ReleaseAnnouncementAnchor">
+                    {vm.displayComposeMenu ? (
+                        <ComposeMenu vm={vm} />
+                    ) : (
+                        <IconButton
+                            onClick={(e) => vm.createChatRoom(e.nativeEvent)}
+                            tooltip={_t("action|new_conversation")}
+                        >
+                            <ComposeIcon color="var(--cpd-color-icon-secondary)" aria-hidden />
+                        </IconButton>
+                    )}
+                </div>
             </Flex>
         </Flex>
     );
