@@ -11,8 +11,6 @@ import { useRoomListViewModel } from "../../../viewmodels/roomlist/RoomListViewM
 import { RoomList } from "./RoomList";
 import { EmptyRoomList } from "./EmptyRoomList";
 import { RoomListPrimaryFilters } from "./RoomListPrimaryFilters";
-import { _t } from "../../../../languageHandler";
-import { ReleaseAnnouncement } from "../../../structures/ReleaseAnnouncement";
 
 /**
  * Host the room list and the (future) room filters
@@ -30,17 +28,9 @@ export function RoomListView(): JSX.Element {
     }
     return (
         <>
-            <ReleaseAnnouncement
-                feature="newRoomList_filter"
-                header={_t("room_list|release_announcement|filter|title")}
-                description={_t("room_list|release_announcement|filter|description")}
-                closeLabel={_t("room_list|release_announcement|next")}
-                placement="right"
-            >
-                <div>
-                    <RoomListPrimaryFilters vm={vm} />
-                </div>
-            </ReleaseAnnouncement>
+            <div>
+                <RoomListPrimaryFilters vm={vm} />
+            </div>
             {listBody}
         </>
     );
