@@ -19,7 +19,7 @@ import { AskToJoinIcon } from "@vector-im/compound-design-tokens/assets/web/icon
 
 import { MatrixClientPeg } from "../../../MatrixClientPeg";
 import dis from "../../../dispatcher/dispatcher";
-import { _t, UserFriendlyError } from "../../../languageHandler";
+import { _t } from "../../../languageHandler";
 import SdkConfig from "../../../SdkConfig";
 import IdentityAuthClient from "../../../IdentityAuthClient";
 import InviteReason from "../elements/InviteReason";
@@ -112,7 +112,8 @@ interface IProps {
 interface IState {
     busy: boolean;
     accountEmails?: string[];
-    invitedEmailMxid?: string;
+    // The email address that was invited. undefined === not yet loaded, null === no associated email
+    invitedEmailMxid?: string | null;
     threePidFetchError?: MatrixError;
     reason?: string;
 }
@@ -165,10 +166,7 @@ class RoomPreviewBar extends React.Component<IProps, IState> {
                     this.props.invitedEmail,
                     identityAccessToken!,
                 );
-                if (!("mxid" in result)) {
-                    throw new UserFriendlyError("room|error_3pid_invite_email_lookup");
-                }
-                this.setState({ invitedEmailMxid: result.mxid });
+                this.setState({ invitedEmailMxid: result.mxid ?? null });
             } catch (err) {
                 this.setState({ threePidFetchError: err as MatrixError });
             }
@@ -212,7 +210,7 @@ class RoomPreviewBar extends React.Component<IProps, IState> {
         }
 
         if (this.props.inviterName) {
-            if (this.props.invitedEmail) {
+            if (this.props.invitedEmail !== undefined) {
                 if (this.state.threePidFetchError) {
                     return MessageCase.OtherThreePIDError;
                 } else if (this.state.accountEmails && !this.state.accountEmails.includes(this.props.invitedEmail)) {
