@@ -8,13 +8,16 @@ Please see LICENSE files in the repository root for full details.
 
 import React from "react";
 import classNames from "classnames";
-import { ShieldIcon, ErrorSolidIcon } from "@vector-im/compound-design-tokens/assets/web/icons";
+import {
+    ShieldIcon,
+    ErrorSolidIcon,
+    ComputerIcon,
+    MobileIcon,
+    WebBrowserIcon,
+    DevicesIcon,
+} from "@vector-im/compound-design-tokens/assets/web/icons";
 
-import { Icon as UnknownDeviceIcon } from "../../../../../res/img/element-icons/settings/unknown-device.svg";
-import { Icon as DesktopIcon } from "../../../../../res/img/element-icons/settings/desktop.svg";
-import { Icon as WebIcon } from "../../../../../res/img/element-icons/settings/web.svg";
-import { Icon as MobileIcon } from "../../../../../res/img/element-icons/settings/mobile.svg";
-import { _t, _td, type TranslationKey } from "../../../../languageHandler";
+import { _t, _td } from "../../../../languageHandler";
 import { type ExtendedDevice } from "./types";
 import { DeviceType } from "../../../../utils/device/parseUserAgent";
 
@@ -25,10 +28,10 @@ interface Props {
 }
 
 const deviceTypeIcon: Record<DeviceType, React.FC<React.SVGProps<SVGSVGElement>>> = {
-    [DeviceType.Desktop]: DesktopIcon,
+    [DeviceType.Desktop]: ComputerIcon,
     [DeviceType.Mobile]: MobileIcon,
-    [DeviceType.Web]: WebIcon,
-    [DeviceType.Unknown]: UnknownDeviceIcon,
+    [DeviceType.Web]: WebBrowserIcon,
+    [DeviceType.Unknown]: DevicesIcon,
 };
 const deviceTypeLabel: Record<DeviceType, TranslationKey> = {
     [DeviceType.Desktop]: _td("settings|sessions|desktop_session"),
