@@ -7,6 +7,7 @@ Please see LICENSE files in the repository root for full details.
 */
 
 import React from "react";
+import { OfflineIcon } from "@vector-im/compound-design-tokens/assets/web/icons";
 
 import { _t } from "../../../languageHandler";
 import AccessibleButton from "../elements/AccessibleButton";
@@ -21,7 +22,7 @@ export default class NonUrgentEchoFailureToast extends React.PureComponent {
     public render(): React.ReactNode {
         return (
             <div className="mx_NonUrgentEchoFailureToast">
-                <span className="mx_NonUrgentEchoFailureToast_icon" />
+                <OfflineIcon />
                 {_t(
                     "error|non_urgent_echo_failure_toast",
                     {},
