@@ -7,6 +7,7 @@ Please see LICENSE files in the repository root for full details.
 
 import { createRoot, type Root } from "react-dom/client";
 import { type Api, type RuntimeModuleConstructor } from "@element-hq/element-web-module-api";
+import { I18nApi } from "@element-hq/web-shared-components";
 
 import { ModuleRunner } from "./ModuleRunner.ts";
 import AliasCustomisations from "../customisations/Alias.ts";
@@ -20,7 +21,6 @@ import UserIdentifierCustomisations from "../customisations/UserIdentifier.ts";
 import { WidgetPermissionCustomisations } from "../customisations/WidgetPermissions.ts";
 import { WidgetVariableCustomisations } from "../customisations/WidgetVariables.ts";
 import { ConfigApi } from "./ConfigApi.ts";
-import { I18nApi } from "./I18nApi.ts";
 import { CustomComponentsApi } from "./customComponentApi";
 import { WatchableProfile } from "./Profile.ts";
 import { NavigationApi } from "./Navigation.ts";
