@@ -30,9 +30,6 @@ export interface IToast<C extends ComponentClass> {
  */
 export default class ToastStore extends EventEmitter {
     private toasts: IToast<any>[] = [];
-    // The count of toasts which have been seen & dealt with in this stack
-    // where the count resets when the stack of toasts clears.
-    private countSeen = 0;
 
     public static sharedInstance(): ToastStore {
         if (!window.mxToastStore) window.mxToastStore = new ToastStore();
@@ -41,7 +38,6 @@ export default class ToastStore extends EventEmitter {
 
     public reset(): void {
         this.toasts = [];
-        this.countSeen = 0;
     }
 
     /**
@@ -68,18 +64,10 @@ export default class ToastStore extends EventEmitter {
     }
 
     public dismissToast(key: string): void {
-        if (this.toasts[0] && this.toasts[0].key === key) {
-            this.countSeen++;
-        }
-
         const length = this.toasts.length;
         this.toasts = this.toasts.filter((t) => t.key !== key);
         if (length !== this.toasts.length) {
             logger.info(`Removed toast with key '${key}'`);
-            if (this.toasts.length === 0) {
-                this.countSeen = 0;
-            }
-
             this.emit("update");
         }
     }
@@ -87,8 +75,4 @@ export default class ToastStore extends EventEmitter {
     public getToasts(): IToast<any>[] {
         return this.toasts;
     }
-
-    public getCountSeen(): number {
-        return this.countSeen;
-    }
 }
