@@ -6,12 +6,11 @@ Please see LICENSE files in the repository root for full details.
 */
 
 import { MatrixEventEvent } from "matrix-js-sdk/src/matrix";
+import { type TextualEventViewSnapshot, BaseViewModel } from "@element-hq/web-shared-components";
 
 import { type EventTileTypeProps } from "../../events/EventTileFactory";
 import { MatrixClientPeg } from "../../MatrixClientPeg";
 import { textForEvent } from "../../TextForEvent";
-import { type TextualEventViewSnapshot } from "../../shared-components/event-tiles/TextualEventView/TextualEventView";
-import { BaseViewModel } from "../base/BaseViewModel";
 
 export class TextualEventViewModel extends BaseViewModel<TextualEventViewSnapshot, EventTileTypeProps> {
     public constructor(props: EventTileTypeProps) {
