@@ -8,17 +8,14 @@ Please see LICENSE files in the repository root for full details.
 
 export const REPEATABLE_DATE = new Date(2022, 10, 17, 16, 58, 32, 517);
 
+const RealDateTimeFormat = global.Intl.DateTimeFormat;
+
 // allow setting default locale and set timezone
 // defaults to en-GB / Europe/London
 // so tests run the same everywhere
 export const mockIntlDateTimeFormat = (defaultLocale = "en-GB", defaultTimezone = "Europe/London"): void => {
-    // unmock so we can use real DateTimeFormat in mockImplementation
-    if (jest.isMockFunction(global.Intl.DateTimeFormat)) {
-        unmockIntlDateTimeFormat();
-    }
-    const DateTimeFormat = Intl.DateTimeFormat;
     jest.spyOn(global.Intl, "DateTimeFormat").mockImplementation(
-        (locale, options) => new DateTimeFormat(locale || defaultLocale, { ...options, timeZone: defaultTimezone }),
+        (locale, options) => new RealDateTimeFormat(locale || defaultLocale, { ...options, timeZone: defaultTimezone }),
     );
 };
 
