@@ -32,6 +32,7 @@ import {
     type GroupCall,
     HistoryVisibility,
     type ICreateRoomOpts,
+    type EventStatus,
 } from "matrix-js-sdk/src/matrix";
 import { KnownMembership } from "matrix-js-sdk/src/types";
 import { normalize } from "matrix-js-sdk/src/utils";
@@ -207,6 +208,7 @@ export function createTestClient(): MatrixClient {
             });
         }),
         getAccountDataFromServer: jest.fn(),
+
         mxcUrlToHttp: jest.fn().mockImplementation((mxc: string) => `http://this.is.a.url/${mxc.substring(6)}`),
         setAccountData: jest.fn(),
         deleteAccountData: jest.fn(),
@@ -302,6 +304,7 @@ export function createTestClient(): MatrixClient {
                 room_id: roomId,
             });
         }),
+        resendEvent: jest.fn().mockResolvedValue({}),
 
         _unstable_sendDelayedEvent: jest.fn(),
         _unstable_sendDelayedStateEvent: jest.fn(),
@@ -310,7 +313,7 @@ export function createTestClient(): MatrixClient {
         _unstable_sendScheduledDelayedEvent: jest.fn(),
         _unstable_sendStickyEvent: jest.fn(),
         _unstable_sendStickyDelayedEvent: jest.fn(),
-
+        _unstable_getRTCTransports: jest.fn(),
         searchUserDirectory: jest.fn().mockResolvedValue({ limited: false, results: [] }),
         setDeviceVerified: jest.fn(),
         joinRoom: jest.fn(),
@@ -401,6 +404,7 @@ type MakeEventProps = MakeEventPassThruProps & {
     // eslint-disable-next-line camelcase
     prev_content?: IContent;
     unsigned?: IUnsigned;
+    status?: EventStatus;
 };
 
 export const mkRoomCreateEvent = (userId: string, roomId: string, content?: IContent): MatrixEvent => {
@@ -481,6 +485,9 @@ export function mkEvent(opts: MakeEventProps): MatrixEvent {
             getMxcAvatarUrl: () => {},
         } as unknown as RoomMember;
     }
+    if (opts.status !== undefined) {
+        mxEvent.status = opts.status;
+    }
     return mxEvent;
 }
 
@@ -701,7 +708,7 @@ export function mkStubRoom(
         getMembersWithMembership: jest.fn().mockReturnValue([]),
         getMxcAvatarUrl: () => "mxc://avatar.url/room.png",
         getMyMembership: jest.fn().mockReturnValue(KnownMembership.Join),
-        getPendingEvents: () => [] as MatrixEvent[],
+        getPendingEvents: jest.fn().mockReturnValue([]),
         getReceiptsForEvent: jest.fn().mockReturnValue([]),
         getRecommendedVersion: jest.fn().mockReturnValue(Promise.resolve("")),
         getThreads: jest.fn().mockReturnValue([]),
