@@ -11,13 +11,8 @@ import { render } from "jest-matrix-react";
 
 import SdkConfig from "../../../../src/SdkConfig";
 import { ErrorView, UnsupportedBrowserView } from "../../../../src/async-components/structures/ErrorView";
-import { setupLanguageMock } from "../../../setup/setupLanguage";
 
 describe("<ErrorView />", () => {
-    beforeEach(() => {
-        setupLanguageMock();
-    });
-
     it("should match snapshot", () => {
         const { asFragment } = render(<ErrorView title="TITLE" messages={["MSG1", "MSG2"]} />);
         expect(asFragment()).toMatchSnapshot();
@@ -26,7 +21,6 @@ describe("<ErrorView />", () => {
 
 describe("<UnsupportedBrowserView />", () => {
     beforeEach(() => {
-        setupLanguageMock();
         SdkConfig.put({});
     });
 
