@@ -11,7 +11,7 @@ import React from "react";
 import { EventEmitter } from "events";
 import { type MatrixEvent, Room, RoomMember, type Thread, ReceiptType } from "matrix-js-sdk/src/matrix";
 import { KnownMembership } from "matrix-js-sdk/src/types";
-import { render } from "jest-matrix-react";
+import { render, within } from "jest-matrix-react";
 
 import MessagePanel, { shouldFormContinuation } from "../../../../src/components/structures/MessagePanel";
 import SettingsStore from "../../../../src/settings/SettingsStore";
@@ -794,8 +794,8 @@ describe("MessagePanel", function () {
 
         const tiles = container.getElementsByClassName("mx_EventTile");
         expect(tiles.length).toEqual(2);
-        expect(tiles[0].querySelector(".mx_EventTile_receiptSent")).toBeTruthy();
-        expect(tiles[1].querySelector(".mx_EventTile_receiptSent")).toBeFalsy();
+        expect(within(tiles[0] as HTMLElement).queryByRole("status")).toHaveAccessibleName("Your message was sent");
+        expect(within(tiles[1] as HTMLElement).queryByRole("status")).not.toBeInTheDocument();
     });
 
     it("should set lastSuccessful=false on non-last event if last event has a receipt from someone else", () => {
@@ -830,8 +830,8 @@ describe("MessagePanel", function () {
 
         const tiles = container.getElementsByClassName("mx_EventTile");
         expect(tiles.length).toEqual(2);
-        expect(tiles[0].querySelector(".mx_EventTile_receiptSent")).toBeFalsy();
-        expect(tiles[1].querySelector(".mx_EventTile_receiptSent")).toBeFalsy();
+        expect(within(tiles[0] as HTMLElement).queryByRole("status")).not.toBeInTheDocument();
+        expect(within(tiles[1] as HTMLElement).queryByRole("status")).not.toBeInTheDocument();
     });
 });
 
