@@ -33,6 +33,8 @@ import { SettingLevel } from "../../../../../src/settings/SettingLevel";
 import defaultDispatcher from "../../../../../src/dispatcher/dispatcher";
 import SdkConfig from "../../../../../src/SdkConfig";
 import { Action } from "../../../../../src/dispatcher/actions";
+import { MetaSpace } from "../../../../../src/stores/spaces";
+import SpaceStore from "../../../../../src/stores/spaces/SpaceStore.ts";
 
 jest.useFakeTimers();
 
@@ -699,4 +701,29 @@ describe("Spotlight Dialog", () => {
             expect(keyboardPrompt?.textContent).not.toContain("→");
         });
     });
+
+    describe("metaspaces", () => {
+        beforeEach(() => {
+            jest.spyOn(SpaceStore.instance, "enabledMetaSpaces", "get").mockReturnValue([
+                MetaSpace.Home,
+                MetaSpace.Favourites,
+                MetaSpace.People,
+                MetaSpace.Orphans,
+            ]);
+        });
+
+        it.each([MetaSpace.Home, MetaSpace.Favourites, MetaSpace.People])(
+            "should show metaspace %s",
+            async (metaSpace) => {
+                const onFinished = jest.fn();
+                const { asFragment, container } = render(
+                    <SpotlightDialog initialText={metaSpace.split("-")[0]} onFinished={onFinished} />,
+                );
+                await waitFor(() =>
+                    expect(container.querySelector(".mx_SpotlightDialog_metaspaceResult")).toBeInTheDocument(),
+                );
+                expect(asFragment()).toMatchSnapshot();
+            },
+        );
+    });
 });
