@@ -8,9 +8,8 @@ Please see LICENSE files in the repository root for full details.
 
 import React from "react";
 import { Room, type MatrixClient } from "matrix-js-sdk/src/matrix";
-import { type ClientWidgetApi, type IWidget, MatrixWidgetType } from "matrix-widget-api";
-import { type Optional } from "matrix-events-sdk";
-import { act, render, type RenderResult, waitForElementToBeRemoved, waitFor } from "jest-matrix-react";
+import { type IWidget, MatrixWidgetType } from "matrix-widget-api";
+import { act, render, waitForElementToBeRemoved, waitFor } from "jest-matrix-react";
 import userEvent from "@testing-library/user-event";
 import {
     type ApprovalOpts,
@@ -35,7 +34,7 @@ import AppTile from "../../../../../src/components/views/elements/AppTile";
 import { Container, WidgetLayoutStore } from "../../../../../src/stores/widgets/WidgetLayoutStore";
 import AppsDrawer from "../../../../../src/components/views/rooms/AppsDrawer";
 import { ElementWidgetCapabilities } from "../../../../../src/stores/widgets/ElementWidgetCapabilities";
-import { ElementWidget } from "../../../../../src/stores/widgets/StopGapWidget";
+import { ElementWidget, type WidgetMessaging } from "../../../../../src/stores/widgets/WidgetMessaging";
 import { WidgetMessagingStore } from "../../../../../src/stores/widgets/WidgetMessagingStore";
 import { ModuleRunner } from "../../../../../src/modules/ModuleRunner";
 import { RoomPermalinkCreator } from "../../../../../src/utils/permalinks/Permalinks";
@@ -52,6 +51,8 @@ jest.mock("../../../../../src/stores/OwnProfileStore", () => ({
     },
 }));
 
+const realGetValue = SettingsStore.getValue;
+
 describe("AppTile", () => {
     let cli: MatrixClient;
     let sdkContext: SdkContextClass;
@@ -107,25 +108,40 @@ describe("AppTile", () => {
             if (roomId === "r2") return [app2];
             return [];
         });
+    });
+
+    afterAll(async () => {
+        jest.restoreAllMocks();
+    });
+
+    beforeEach(async () => {
+        // Do not carry across settings from previous tests
+        SettingsStore.reset();
+        sdkContext = new SdkContextClass();
+        // @ts-ignore
+        await WidgetMessagingStore.instance.onReady();
 
         // Wake up various stores we rely on
         WidgetLayoutStore.instance.useUnitTestClient(cli);
         // @ts-ignore
         await WidgetLayoutStore.instance.onReady();
+
         RightPanelStore.instance.useUnitTestClient(cli);
         // @ts-ignore
         await RightPanelStore.instance.onReady();
     });
 
-    beforeEach(() => {
-        sdkContext = new SdkContextClass();
+    afterEach(async () => {
         jest.spyOn(SettingsStore, "getValue").mockRestore();
+        // @ts-ignore
+        await WidgetLayoutStore.instance.onNotReady();
+        // @ts-ignore
+        await RightPanelStore.instance.onNotReady();
     });
 
     it("destroys non-persisted right panel widget on room change", async () => {
         // Set up right panel state
-        const realGetValue = SettingsStore.getValue;
-        const mockSettings = jest.spyOn(SettingsStore, "getValue").mockImplementation((name, roomId) => {
+        jest.spyOn(SettingsStore, "getValue").mockImplementation((name, roomId) => {
             if (name !== "RightPanel.phases") return realGetValue(name, roomId);
             if (roomId === "r1") {
                 return {
@@ -188,8 +204,6 @@ describe("AppTile", () => {
 
         expect(renderResult.queryByText("Example 1")).not.toBeInTheDocument();
         expect(ActiveWidgetStore.instance.isLive("1", "r1")).toBe(false);
-
-        mockSettings.mockRestore();
     });
 
     it("distinguishes widgets with the same ID in different rooms", async () => {
@@ -326,50 +340,57 @@ describe("AppTile", () => {
         expect(ActiveWidgetStore.instance.isLive("1", "r1")).toBe(true);
     });
 
-    afterAll(async () => {
-        // @ts-ignore
-        await WidgetLayoutStore.instance.onNotReady();
-        // @ts-ignore
-        await RightPanelStore.instance.onNotReady();
-        jest.restoreAllMocks();
-    });
-
     describe("for a pinned widget", () => {
-        let renderResult: RenderResult;
         let moveToContainerSpy: jest.SpyInstance<void, [room: Room, widget: IWidget, toContainer: Container]>;
-
         beforeEach(async () => {
-            renderResult = render(
+            moveToContainerSpy = jest.spyOn(WidgetLayoutStore.instance, "moveToContainer");
+        });
+
+        it("should render", async () => {
+            const renderResult = render(
                 <MatrixClientContext.Provider value={cli}>
                     <AppTile key={app1.id} app={app1} room={r1} />
                 </MatrixClientContext.Provider>,
             );
-
-            moveToContainerSpy = jest.spyOn(WidgetLayoutStore.instance, "moveToContainer");
             await waitForElementToBeRemoved(() => renderResult.queryByRole("progressbar"));
-        });
-
-        it("should render", () => {
             const { asFragment } = renderResult;
 
             expect(asFragment()).toMatchSnapshot(); // Take a snapshot of the pinned widget
         });
 
-        it("should not display the »Popout widget« button", () => {
+        it("should not display the »Popout widget« button", async () => {
+            const renderResult = render(
+                <MatrixClientContext.Provider value={cli}>
+                    <AppTile key={app1.id} app={app1} room={r1} />
+                </MatrixClientContext.Provider>,
+            );
+            await waitForElementToBeRemoved(() => renderResult.queryByRole("progressbar"));
             expect(renderResult.queryByLabelText("Popout widget")).not.toBeInTheDocument();
         });
 
         it("clicking 'minimise' should send the widget to the right", async () => {
+            const renderResult = render(
+                <MatrixClientContext.Provider value={cli}>
+                    <AppTile key={app1.id} app={app1} room={r1} />
+                </MatrixClientContext.Provider>,
+            );
+            await waitForElementToBeRemoved(() => renderResult.queryByRole("progressbar"));
             await userEvent.click(renderResult.getByLabelText("Minimise"));
             expect(moveToContainerSpy).toHaveBeenCalledWith(r1, app1, Container.Right);
         });
 
         it("clicking 'maximise' should send the widget to the center", async () => {
+            const renderResult = render(
+                <MatrixClientContext.Provider value={cli}>
+                    <AppTile key={app1.id} app={app1} room={r1} />
+                </MatrixClientContext.Provider>,
+            );
+            await waitForElementToBeRemoved(() => renderResult.queryByRole("progressbar"));
             await userEvent.click(renderResult.getByLabelText("Maximise"));
             expect(moveToContainerSpy).toHaveBeenCalledWith(r1, app1, Container.Center);
         });
 
-        it("should render permission request", () => {
+        it("should render permission request", async () => {
             jest.spyOn(ModuleRunner.instance, "invoke").mockImplementation((lifecycleEvent, opts, widgetInfo) => {
                 if (lifecycleEvent === WidgetLifecycle.PreLoadRequest && (widgetInfo as WidgetInfo).id === app1.id) {
                     (opts as ApprovalOpts).approved = false;
@@ -377,21 +398,17 @@ describe("AppTile", () => {
             });
 
             // userId and creatorUserId are different
-            const renderResult = render(
+            const { container, asFragment, queryByRole } = render(
                 <MatrixClientContext.Provider value={cli}>
                     <AppTile key={app1.id} app={app1} room={r1} userId="@user1" creatorUserId="@userAnother" />
                 </MatrixClientContext.Provider>,
             );
-
-            const { container, asFragment } = renderResult;
-
             expect(container.querySelector(".mx_Spinner")).toBeFalsy();
+            expect(queryByRole("button", { name: "Continue" })).toBeInTheDocument();
             expect(asFragment()).toMatchSnapshot();
-
-            expect(renderResult.queryByRole("button", { name: "Continue" })).toBeInTheDocument();
         });
 
-        it("should not display 'Continue' button on permission load", () => {
+        it("should not display 'Continue' button on permission load", async () => {
             jest.spyOn(ModuleRunner.instance, "invoke").mockImplementation((lifecycleEvent, opts, widgetInfo) => {
                 if (lifecycleEvent === WidgetLifecycle.PreLoadRequest && (widgetInfo as WidgetInfo).id === app1.id) {
                     (opts as ApprovalOpts).approved = true;
@@ -404,6 +421,7 @@ describe("AppTile", () => {
                     <AppTile key={app1.id} app={app1} room={r1} userId="@user1" creatorUserId="@userAnother" />
                 </MatrixClientContext.Provider>,
             );
+            await waitForElementToBeRemoved(() => renderResult.queryByRole("progressbar"));
 
             expect(renderResult.queryByRole("button", { name: "Continue" })).not.toBeInTheDocument();
         });
@@ -411,13 +429,23 @@ describe("AppTile", () => {
         describe("for a maximised (centered) widget", () => {
             beforeEach(() => {
                 jest.spyOn(WidgetLayoutStore.instance, "isInContainer").mockImplementation(
-                    (room: Optional<Room>, widget: IWidget, container: Container) => {
+                    (room: Room | null, widget: IWidget, container: Container) => {
                         return room === r1 && widget === app1 && container === Container.Center;
                     },
                 );
             });
 
+            afterEach(() => {
+                jest.spyOn(WidgetLayoutStore.instance, "isInContainer").mockRestore();
+            });
+
             it("clicking 'un-maximise' should send the widget to the top", async () => {
+                const renderResult = render(
+                    <MatrixClientContext.Provider value={cli}>
+                        <AppTile key={app1.id} app={app1} room={r1} />
+                    </MatrixClientContext.Provider>,
+                );
+                await waitForElementToBeRemoved(() => renderResult.queryByRole("progressbar"));
                 await userEvent.click(renderResult.getByLabelText("Un-maximise"));
                 expect(moveToContainerSpy).toHaveBeenCalledWith(r1, app1, Container.Top);
             });
@@ -425,46 +453,42 @@ describe("AppTile", () => {
 
         describe("with an existing widgetApi with requiresClient = false", () => {
             beforeEach(() => {
-                const api = {
-                    hasCapability: (capability: ElementWidgetCapabilities): boolean => {
-                        return !(capability === ElementWidgetCapabilities.RequiresClient);
-                    },
-                    once: () => {},
+                const messaging = {
+                    on: () => {},
+                    off: () => {},
+                    prepare: async () => {},
                     stop: () => {},
-                } as unknown as ClientWidgetApi;
+                    widgetApi: {
+                        hasCapability: (capability: ElementWidgetCapabilities): boolean => {
+                            return !(capability === ElementWidgetCapabilities.RequiresClient);
+                        },
+                    },
+                } as unknown as WidgetMessaging;
 
                 const mockWidget = new ElementWidget(app1);
-                WidgetMessagingStore.instance.storeMessaging(mockWidget, r1.roomId, api);
+                WidgetMessagingStore.instance.storeMessaging(mockWidget, r1.roomId, messaging);
+            });
 
-                renderResult = render(
+            it("should display the »Popout widget« button", async () => {
+                const renderResult = render(
                     <MatrixClientContext.Provider value={cli}>
                         <AppTile key={app1.id} app={app1} room={r1} />
                     </MatrixClientContext.Provider>,
                 );
-            });
-
-            it("should display the »Popout widget« button", () => {
+                await waitForElementToBeRemoved(() => renderResult.queryByRole("progressbar"));
                 expect(renderResult.getByLabelText("Popout widget")).toBeInTheDocument();
             });
         });
     });
 
     describe("for a persistent app", () => {
-        let renderResult: RenderResult;
-
-        beforeEach(async () => {
-            renderResult = render(
+        it("should render", async () => {
+            const { asFragment, queryByRole } = render(
                 <MatrixClientContext.Provider value={cli}>
-                    <AppTile key={app1.id} app={app1} fullWidth={true} room={r1} miniMode={true} showMenubar={false} />
+                    <AppTile key={app1.id} app={app1} room={r1} fullWidth={true} miniMode={true} showMenubar={false} />
                 </MatrixClientContext.Provider>,
             );
-
-            await waitForElementToBeRemoved(() => renderResult.queryByRole("progressbar"));
-        });
-
-        it("should render", async () => {
-            const { asFragment } = renderResult;
-
+            await waitForElementToBeRemoved(() => queryByRole("progressbar"));
             expect(asFragment()).toMatchSnapshot();
         });
     });
