@@ -10,6 +10,7 @@ import React from "react";
 import { act, fireEvent, render, screen, waitFor } from "jest-matrix-react";
 import { mocked } from "jest-mock";
 import {
+    EventStatus,
     EventType,
     type IEventDecryptionResult,
     type MatrixClient,
@@ -27,6 +28,7 @@ import {
     EventShieldReason,
 } from "matrix-js-sdk/src/crypto-api";
 import { mkEncryptedMatrixEvent } from "matrix-js-sdk/src/testing";
+import { getByTestId } from "@testing-library/dom";
 
 import EventTile, { type EventTileProps } from "../../../../../src/components/views/rooms/EventTile";
 import MatrixClientContext from "../../../../../src/contexts/MatrixClientContext";
@@ -332,6 +334,28 @@ describe("EventTile", () => {
             expect(e2eIcons[0]).toHaveAccessibleName(expectedText);
         });
 
+        it("shows the correct reason code for a forwarded message", async () => {
+            mxEvent = await mkEncryptedMatrixEvent({
+                plainContent: { msgtype: "m.text", body: "msg1" },
+                plainType: "m.room.message",
+                sender: "@alice:example.org",
+                roomId: room.roomId,
+            });
+            // @ts-ignore assignment to private member
+            mxEvent.keyForwardedBy = "@bob:example.org";
+            eventToEncryptionInfoMap.set(mxEvent.getId()!, {
+                shieldColour: EventShieldColour.GREY,
+                shieldReason: EventShieldReason.AUTHENTICITY_NOT_GUARANTEED,
+            } as EventEncryptionInfo);
+
+            const { container } = getComponent();
+
+            const e2eIcon = await waitFor(() => getByTestId(container, "e2e-padlock"));
+            expect(e2eIcon).toHaveAccessibleName(
+                "@bob:example.org (@bob:example.org) shared this message since you were not in the room when it was sent.",
+            );
+        });
+
         describe("undecryptable event", () => {
             filterConsole("Error decrypting event");
 
@@ -614,4 +638,20 @@ describe("EventTile", () => {
         // The event tile should now show the not encrypted status
         await waitFor(() => expect(screen.getByText("Not encrypted")).toBeInTheDocument());
     });
+
+    it.each([
+        [EventStatus.NOT_SENT, "Failed to send"],
+        [EventStatus.SENDING, "Sending your message…"],
+        [EventStatus.ENCRYPTING, "Encrypting your message…"],
+    ])("should display %s status icon", (eventSendStatus, text) => {
+        const ownEvent = mkMessage({
+            room: room.roomId,
+            user: client.getSafeUserId(),
+            msg: "Hello world!",
+            event: true,
+        });
+        const { getByRole } = getComponent({ mxEvent: ownEvent, eventSendStatus });
+
+        expect(getByRole("status")).toHaveAccessibleName(text);
+    });
 });
