@@ -8,6 +8,7 @@ Please see LICENSE files in the repository root for full details.
 */
 
 import { sleep } from "matrix-js-sdk/src/utils";
+import { waitFor } from "jest-matrix-react";
 
 import SettingsStore from "../../../../src/settings/SettingsStore";
 import { SettingLevel } from "../../../../src/settings/SettingLevel";
@@ -155,5 +156,33 @@ describe("FontWatcher", function () {
             // baseFontSize should be cleared
             expect(SettingsStore.getValue("baseFontSizeV2")).toBe(0);
         });
+
+        it("should trigger migration when dispatched", async () => {
+            await watcher!.start();
+
+            await SettingsStore.setValue("baseFontSizeV2", null, SettingLevel.DEVICE, 18);
+            defaultDispatcher.fire(Action.MigrateBaseFontSize);
+
+            await waitFor(() => {
+                // 18px - 16px (default browser font size) = 2px
+                expect(SettingsStore.getValue("fontSizeDelta")).toBe(2);
+                // baseFontSizeV2 should be cleared
+                expect(SettingsStore.getValue("baseFontSizeV2")).toBe(0);
+            });
+        });
+    });
+
+    it("should update root font size with positive delta", async () => {
+        await new FontWatcher().start();
+
+        defaultDispatcher.dispatch({
+            action: Action.UpdateFontSizeDelta,
+            delta: 2,
+        });
+
+        await waitFor(() => {
+            const rootFontSize = document.querySelector<HTMLElement>(":root")!.style.fontSize;
+            expect(rootFontSize).toContain("2px");
+        });
     });
 });
