@@ -7,7 +7,7 @@ Please see LICENSE files in the repository root for full details.
 */
 
 import { mocked, type MockedObject } from "jest-mock";
-import fetchMockJest from "fetch-mock-jest";
+import fetchMock from "@fetch-mock/jest";
 import {
     type MatrixClient,
     ClientEvent,
@@ -792,7 +792,7 @@ describe("ElementWidgetDriver", () => {
                 return null;
             });
 
-            fetchMockJest.get("https://example.com/_matrix/media/v3/download/example.com/test_file", "test contents");
+            fetchMock.get("https://example.com/_matrix/media/v3/download/example.com/test_file", "test contents");
 
             const result = await driver.downloadFile("mxc://example.com/test_file");
             // A type test is impossible here because of
